\name{da.mix}
\alias{da.mix}
\title{
  Data Augmentation for Unrestricted General Location Model
}
\description{
  Markov Chain Monte Carlo method for generating posterior draws of the
  parameters of the unrestricted general location model, given a matrix of
  incomplete mixed data.  At each step, missing data are randomly imputed
  under the current parameter, and a new parameter value is drawn from its
  posterior distribution given the completed data.  After a suitable
  number of steps are taken, the resulting value of the parameter may be
  regarded as a random draw from its observed-data posterior
  distribution. May be used together with \code{\link{imp.mix}} to create
  multiple imputations of the missing data.
}
\usage{
da.mix(s, start, steps=1, prior=0.5, showits=FALSE)
}
\arguments{
  \item{s}{
    summary list of an incomplete data matrix created by the
    function \code{\link{prelim.mix}}.
  }
  \item{start}{
    starting value of the parameter. This is a parameter list
    such as one created by the function \code{\link{em.mix}}.
  }
  \item{steps}{
    number of data augmentation steps to be taken.
  }
  \item{prior}{
    Optional vector or array of hyperparameter(s) for a Dirichlet prior
    distribution.  The default is the Jeffreys prior (all hyperparameters
    = .5). If structural zeros appear in the table, prior counts for these
    cells should be set to \code{NA}.
  }
  \item{showits}{
    if \code{TRUE}, reports the iterations so the user can monitor the
    progress of the algorithm. 
}}
\value{
  A new parameter list. The parameter can be put into a more
  understandable format by the function \code{getparam.mix}.
}
\details{
  The prior distribution used by this function is a combination of a
  Dirichlet prior for the cell probabilities, an improper uniform prior
  for the within-cell means, and the improper Jeffreys prior for the
  covariance matrix. The posterior distribution is not guaranteed to
  exist, especially in sparse-data situations. If this seems to be a
  problem, then better results may be obtained by imposing restrictions
  on the parameters; see \code{\link{ecm.mix}} and \code{\link{dabipf.mix}}.
}
\note{
  The random number generator seed must be set at least once by the
  function \code{rngseed} before this function can be used.
}
\references{
  Schafer, J. L. (1996) \emph{Analysis of Incomplete Multivariate Data.}
  Chapman \& Hall, Chapter 9.
}
\seealso{
  \code{\link{prelim.mix}}, \code{\link{getparam.mix}},
  \code{\link{em.mix}}, and \code{\link{rngseed}}.
}
\examples{
data(stlouis)
s <- prelim.mix(stlouis,3)  # preliminary manipulations
thetahat <- em.mix(s) # find ML estimate
rngseed(1234567)   # set random number generator seed
newtheta <- da.mix(s, thetahat, steps=100, showits=TRUE)  # take 100 steps
ximp1 <- imp.mix(s, newtheta) # impute under newtheta
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{dabipf.mix}
\alias{dabipf.mix}
\title{
  Data Augmentation/Bayesian IPF Algorithm for Restricted General Location
Models
}
\description{
  Markov Chain Monte Carlo method for generating posterior draws of the
  parameters of the unrestricted general location model, given a matrix
  of incomplete mixed data.  After a suitable number of steps are taken,
  the resulting value of the parameter may be regarded as a random draw
  from its observed-data posterior distribution. May be used together
  with \code{\link{imp.mix}} to create multiple imputations
  of the missing data.
}
\usage{
dabipf.mix(s, margins, design, start, steps=1, prior=0.5, 
           showits=FALSE)
}
\arguments{
\item{s}{
  summary list of an incomplete data matrix created by the
  function \code{\link{prelim.mix}}.
}
\item{margins}{
  vector describing the sufficient configurations or margins in the
  desired loglinear model. The variables are ordered in the original
  order of the columns of \code{x}, so that 1 refers to \code{x[,1]},
  2 refers to
  \code{x[,2]}, and so on.  A margin is described by the factors not summed
  over, and margins are separated by zeros.  Thus c(1,2,0,2,3,0,1,3)
  would indicate the (1,2), (2,3), and (1,3) margins in a three-way
  table, i.e., the model of no three-way association.
}
\item{design}{
  design matrix specifying the relationship of the continuous
  variables to the categorical ones. The dimension is \code{c(D,r)} where
  \eqn{D} is the number of cells in the contingency table, and \eqn{r} is the
  number of effects which must be less than or equal to \eqn{D}. The
  order of the rows corresponds to the storage order of the cell
  probabilities in the contingency table; see \code{\link{getparam.mix}} for
  details.
}
\item{start}{
  starting value of the parameter. This is a parameter list
  such as one created by this function or by \code{\link{ecm.mix}}.
}
\item{steps}{
  number of steps of data augmentation-Bayesian IPF to be taken.
}
\item{prior}{
  Optional vector or array of hyperparameter(s) for a Dirichlet prior
  distribution.  The default is the Jeffreys prior (all hyperparameters
  = .5). If structural zeros appear in the table, prior counts for these
  cells should be set to \code{NA}.
}
\item{showits}{
  if \code{TRUE}, reports the iterations so the user can monitor the
  progress of the algorithm. 
}}
\value{
  a new parameter list. The parameter can be put into a more
  understandable format by the function \code{\link{getparam.mix}}.
}
\details{
  The prior distribution used by this function is a combination of a
  constrained Dirichlet prior for the cell probabilities, an improper
  uniform prior for the regression coefficients, and the improper Jeffreys
  prior for the covariance matrix. The posterior distribution is not
  guaranteed to exist, especially in sparse-data situations. If this
  seems to be a problem, then better results may be obtained by imposing
  restrictions further restrictions on the parameters.
}
\note{
  The random number generator seed must be set at least once by the
  function \code{\link{rngseed}} before this function can be used.


  The starting value should satisfy the restrictions of the model and
  should lie in the interior of the parameter space. A suitable starting
  value can be obtained by running \code{\link{ecm.mix}},
  possibly with the prior 
  hyperparameters set to some value greater than 1, to ensure that the
  mode lies in the interior.
}
\references{
  Schafer, J. L. (1996) \emph{Analysis of Incomplete Multivariate Data.}
  Chapman \& Hall, Chapter 9.
}
\seealso{
  \code{\link{prelim.mix}}, \code{\link{getparam.mix}},
  \code{\link{ecm.mix}}, \code{\link{rngseed}}, \code{\link{imp.mix}}.
}
\examples{
data(stlouis)
s <- prelim.mix(stlouis,3)      # do preliminary manipulations
margins <- c(1,2,3)       # saturated contingency table model
design <- diag(rep(1,12))  # identity matrix  D=no of cells
thetahat <- ecm.mix(s,margins,design) # find ML estimate
rngseed(1234567)       # random generator seed
newtheta <- dabipf.mix(s,margins,design,thetahat,steps=200)
ximp <- imp.mix(s,newtheta,stlouis)   # impute under newtheta
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{ecm.mix}
\alias{ecm.mix}
\title{
ECM Algorithm for Restricted General Location Model
}
\description{
Computes maximum-likelihood estimates  for the parameters of the
general location model from an incomplete mixed dataset.
}
\usage{
ecm.mix(s, margins, design, start, prior=1, maxits=1000, 
        showits=TRUE, eps=0.0001)
}
\arguments{
\item{s}{
  summary list of an incomplete data matrix \code{x} produced by
  the function \code{\link{prelim.mix}}.
}
\item{margins}{
vector describing the sufficient configurations or margins in the
desired loglinear model. The variables are ordered in the original
order of the columns of \code{x}, so that 1 refers to \code{x[,1]}, 2 refers to
\code{x[,2]}, and so on.  A margin is described by the factors not summed
over, and margins are separated by zeros.  Thus c(1,2,0,2,3,0,1,3)
would indicate the (1,2), (2,3), and (1,3) margins in a three-way
table, i.e., the model of no three-way association.
}
\item{design}{
  design matrix specifying the relationship of the continuous
  variables to the categorical ones. The dimension is \code{c(D,r)} where
  \eqn{D} is the number of cells in the contingency table, and \eqn{r} is the
  number of effects which must be less than or equal to \eqn{D}. The
  order of the rows corresponds to the storage order of the cell
  probabilities in the contingency table; see \code{\link{getparam.mix}} for
  details.
}
\item{start}{
  optional starting value of the parameter. This is a list such as one
  created by this function or by \code{\link{dabipf.mix}}. If structural zeros
  appear in the table, \code{start$pi} should contain zeros in those
  positions and ones elsewhere. If no starting value is supplied,
  \code{\link{ecm.mix}} chooses its own appropriate starting value.
}
\item{prior}{
  Optional vector or array of hyperparameter(s) for a Dirichlet prior
  distribution. By default, uses a uniform prior on the cell
  probabilities. ECM finds the posterior mode, which under
  a uniform prior is the same as a maximum-likelihood estimate. If
  structural zeros appear in the table, hyperparameters for those cells
  should be set to \code{NA}..
}
\item{maxits}{
  maximum number of iterations performed. The algorithm will stop if the
  parameter still has not converged after this many iterations.
}
\item{showits}{
  if \code{TRUE}, reports the iterations of ECM so the user can monitor
  the progress of the algorithm.
}
\item{eps}{
  optional convergence criterion. The algorithm stops when the maximum
  relative difference in every parameter from one iteration to the next
  is less than or equal to this value.
}}
\value{
  a list representing the maximum-likelihood estimates (or posterior
  mode) of the normal parameters. This list contains cell probabilities,
  cell means, and covariances.  The parameter can be transformed back to
  the original scale and put into a more understandable format by the
  function \code{\link{getparam.mix}}.
}
\note{
  If zero cell counts occur in the complete-data table, the maximum
  likelihood estimate may not be unique, and the algorithm may converge
  to different stationary values depending on the starting value. Also,
  if zero cell counts occur in the complete-data table, the ML estimate may
  lie on the boundary of the parameter space.
}
\references{
  Schafer, J. L. (1996) \emph{Analysis of Incomplete Multivariate Data.}
  Chapman \& Hall, Chapter 9.
}
\seealso{
  \code{\link{prelim.mix}}, \code{\link{em.mix}},
  \code{\link{getparam.mix}},
  \code{\link{loglik.mix}}.
}
\examples{
data(stlouis)
s <- prelim.mix(stlouis,3)         # preliminary manipulations
margins <- c(1,2,3)          # saturated loglinear model
design <- diag(rep(1,12))     # identity matrix, D=no of cells
thetahat <- ecm.mix(s,margins,design)  # should be same as em.mix(s)
loglik.mix(s,thetahat)             # loglikelihood at thetahat
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{em.mix}
\alias{em.mix}
\title{
EM Algorithm for Unrestricted General Location Model
}
\description{
  Computes maximum-likelihood estimates for the parameters of the
  unrestricted general location model from an incomplete mixed
  dataset.
}
\usage{
em.mix(s, start, prior=1, maxits=1000, showits=TRUE, eps=0.0001)
}
\arguments{
\item{s}{
  summary list of an incomplete data matrix produced by the function
  \code{\link{prelim.mix}}.
}
\item{start}{
  optional starting value of the parameter.  This is a parameter list in
  packed storage, such as one returned by this function or by
  \code{\link{da.mix}}.
  If structural zeros appear in the contingency table, \code{start$pi} should
  contain zeros in those positions and ones elsewhere. If no starting
  value is supplied, \code{em.mix} chooses its own appropriate starting value.
}
\item{prior}{
  Optional vector or array of hyperparameters for a Dirichlet prior
  distribution. By default, uses a uniform prior on the cell
  probabilities (all hyperparameters set to one). EM algorithm finds the
  posterior mode, which under a uniform prior is the same as a
  maximum-likelihood estimate. If structural zeros appear in the table,
  the corresponding hyperparameters should be set to NA.
}
\item{maxits}{
  maximum number of iterations performed. The algorithm will stop if the
  parameter still has not converged after this many iterations.
}
\item{showits}{
  if \code{TRUE}, reports the iterations of EM so the user can monitor the
  progress of the algorithm.
}
\item{eps}{
  optional convergence criterion. The algorithm stops when the maximum
  relative difference in every parameter from one iteration to the next
  is less than or equal to this value.
}}
\value{
  a list representing the maximum-likelihood estimates (or posterior
  mode) of the normal parameters. This list contains cell probabilities,
  cell means, and covariances.  The parameter can be transformed back to
  the original scale and put into a more understandable format by the
  function \code{\link{getparam.mix}}.
}
\note{
  If zero cell counts occur in the complete-data table, the maximum
  likelihood estimate may not be unique, and the algorithm may converge
  to different stationary values depending on the starting value. Also,
  if zero cell counts occur in the complete-data table, the ML estimate
  may lie on the boundary of the parameter space.
}
\references{
  Schafer, J. L. (1996) \emph{Analysis of Incomplete Multivariate Data.}
  Chapman \& Hall, Chapter 9.
}
\seealso{
  \code{\link{prelim.mix}}, \code{\link{getparam.mix}},
  and \code{\link{ecm.mix}}.
}
\examples{
data(stlouis)
s <- prelim.mix(stlouis,3)    # do preliminary manipulations
thetahat <- em.mix(s)   # compute ML estimate
getparam.mix(s,thetahat, corr=TRUE) # look at estimated parameters
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{getparam.mix}
\alias{getparam.mix}
\title{
Present Parameters of General Location Model in an Understandable Format
}
\description{
Present parameters of general location model in an understandable format.
}
\usage{
getparam.mix(s, theta, corr=FALSE)
}
\arguments{
\item{s}{
  summary list of an incomplete normal data matrix created by the
  function \code{\link{prelim.mix}}.
}
\item{theta}{
  list of parameters such as one produced by the function \code{\link{em.mix}},
  \code{\link{da.mix}}, \code{\link{ecm.mix}}, or \code{\link{dabipf.mix}}.
}
\item{corr}{
  if \code{FALSE}, returns a list containing an array of cell probabilities, 
  a matrix of cell means, and a variance-covariance matrix.
  If \code{TRUE}, returns a list containing an array of cell probabilities,
  a matrix of cell means, a vector of standard deviations, and a correlation
  matrix. 
}}
\value{
  if \code{corr=FALSE}, a list containing the components \code{pi},
  \code{mu} and \code{sigma}; if
  \code{corr=TRUE}, a list containing the components \code{pi}, \code{mu},
  \code{sdv}, and \code{r}.

  The components are:

  \item{pi}{
    array of cell probabilities whose dimensions correspond to the
    columns of the categorical part of $x$. The dimension is
    \code{c(max(x[,1]),max(x[,2]),\dots,max(x[,p]))} where \eqn{p}
    is the number of categorical variables. 
  }
  \item{mu}{
    Matrix of cell means. The dimension is \code{c(q,D)} where \eqn{q} is the
    number of continuous variables in \eqn{x}, and \eqn{D} is
    \code{length(pi)}.  The order of the rows, corresponding to the
    elements of \code{pi}, is the same order we would get by
    vectorizing \code{pi}, as in \code{as.vector(pi)}; it is
    the usual lexicographic order used by S and Fortran, with the
    subscript corresponding to \code{x[,1]} varying the fastest, and the
    subscript corresponding to \code{x[,p]} varying the slowest.
  }
  \item{sigma}{
    matrix of variances and covariances corresponding to the continuous
    variables in \code{x}.
  }
  \item{sdv}{
    vector of standard deviations corresponding to the continuous
    variables in \code{x}.
  }
  \item{r}{
    matrix of correlations corresponding to the continuous
    variables in \code{x}.
}}
\note{
  In a restricted general location model, the matrix of means is
  required to satisfy \code{t(mu)=A\%*\%beta} for a given design matrix
  \code{A}. To obtain \code{beta}, perform a multivariate regression
  of \code{t(mu)} on \code{A} --- for
  example, \code{beta <- lsfit(A, t(mu), intercept=FALSE)$coef}.
}
\references{
  Schafer, J. L. (1996) \emph{Analysis of Incomplete Multivariate Data.}
  Chapman \& Hall, Chapter 9.
}
\seealso{
  \code{\link{prelim.mix}}, \code{\link{em.mix}}, \code{\link{ecm.mix}},
  \code{\link{da.mix}}, \code{\link{dabipf.mix}}.
}
\examples{
data(stlouis)
s <- prelim.mix(stlouis,3)    # do preliminary manipulations
thetahat <- em.mix(s)   # compute ML estimate
getparam.mix(s, thetahat, corr=TRUE)$r   # look at estimated correlations 
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{imp.mix}
\alias{imp.mix}
\title{
Impute Missing Data Under General Location Model
}
\description{
  This function, when used with \code{\link{da.mix}} or
  \code{\link{dabipf.mix}}, can be
  used to create proper multiple imputations of missing data under
  the general location model with or without restrictions.
}
\usage{
imp.mix(s, theta, x)
}
\arguments{
\item{s}{
  summary list of an incomplete data matrix \code{x} created by the
  function \code{\code{prelim.mix}}.
}
\item{theta}{
  value of the parameter under which the missing data are to be
  randomly imputed. This is a parameter list such as one created
  by \code{\link{da.mix}} or \code{\link{dabipf.mix}}.
}
\item{x}{
  the original data matrix used to create the summary list \code{s}. If this
  argument is not supplied, then the data matrix returned by this
  function may disagree slightly with the observed values in \code{x} due to
  rounding errors.
}}
\value{
  a matrix of the same form as \code{x}, but with all missing values filled in
  with simulated values drawn from their predictive distribution given
  the observed data and the specified parameter.
}
\details{
  This function is essentially the I-step of data augmentation. 
}
\note{
  The random number generator seed must be set at least once by the
  function \code{\link{rngseed}} before this function can be used.
}
\references{
  Schafer, J. L. (1996) \emph{Analysis of Incomplete Multivariate Data.}
  Chapman \& Hall, Chapter 9.
}
\seealso{
  \code{\link{prelim.mix}}, \code{\link{da.mix}},
  \code{\link{dabipf.mix}}, \code{\link{rngseed}}
}
\examples{
data(stlouis)
s <- prelim.mix(stlouis,3)    # do preliminary manipulations
thetahat <- em.mix(s)   # ML estimate for unrestricted model
rngseed(1234567)     # set random number generator seed
newtheta <- da.mix(s,thetahat,steps=100) # data augmentation
ximp <- imp.mix(s, newtheta, stlouis)  # impute under newtheta
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{loglik.mix}
\alias{loglik.mix}
\title{
  Loglikelihood for Incomplete Data under the General Location Model
}
\description{
  Calculates the observed-data loglikelihood under the general location 
  model at a user-specified parameter value.
}
\usage{
loglik.mix(s, theta)
}
\arguments{
\item{s}{
  summary list of an incomplete data matrix \code{x} created by
  the function \code{\link{prelim.mix}}.
}
\item{theta}{
  parameter list, such as one produced by \code{\link{ecm.mix}}
  or \code{\link{da.mix}}.
}}
\value{
the value of the loglikelihood function at \code{theta}.
}
\references{
  Schafer, J. L. (1996) \emph{Analysis of Incomplete Multivariate Data.}
  Chapman \& Hall, Chapter 9.
}
\seealso{
\code{\link{prelim.mix}}, \code{\link{em.mix}}, \code{\link{ecm.mix}}.
}
\examples{
data(stlouis)
s <- prelim.mix(stlouis,3)       # preliminary manipulations
thetahat <- em.mix(s)      # MLE under unrestricted general location model
loglik.mix(s, thetahat)  # loglikelihood at thetahat
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{mi.inference}
\alias{mi.inference}
\title{
  Multiple Imputation Inference
}
\description{
  Combines estimates and standard errors from m complete-data analyses
  performed on m imputed datasets to produce a single inference.  Uses
  the technique described by Rubin (1987) for multiple
  imputation inference for a scalar estimand.
}
\usage{
mi.inference(est, std.err, confidence=0.95)
}
\arguments{
\item{est}{
  a list of \eqn{m} (at least 2) vectors representing estimates (e.g.,
  vectors of estimated regression coefficients) from complete-data
  analyses performed on \eqn{m} imputed datasets.
}
\item{std.err}{
  a list of \eqn{m} vectors containing standard errors from the
  complete-data analyses corresponding to the estimates in \code{est}.
}
\item{confidence}{
  desired coverage of interval estimates.
}}
\value{
  a list with the following components, each of which is a vector of the
  same length as the components of \code{est} and \code{std.err}:

  \item{est}{
    the average of the complete-data estimates.
  }
  \item{std.err}{
    standard errors incorporating both the between and the
    within-imputation uncertainty (the square root of the "total
    variance").
    }
    \item{df}{
      degrees of freedom associated with the \eqn{t} reference
      distribution used for interval estimates.
    }
    \item{signif}{
      P-values for the two-tailed hypothesis tests that the estimated
      quantities are equal to zero.
    }
    \item{lower}{
      lower limits of the (100*confidence)\% interval estimates.
    }
    \item{upper}{
      upper limits of the (100*confidence)\% interval estimates.
    }
    \item{r}{
      estimated relative increases in variance due to nonresponse.
    }
    \item{fminf}{
      estimated fractions of missing information.
  }}
\section{Method}{
  Uses the method described on pp. 76-77 of Rubin (1987) for combining
  the complete-data estimates from $m$ imputed datasets
  for a scalar estimand. Significance levels and interval estimates are
  approximately valid for each one-dimensional estimand, not for all of
  them jointly.
}
\references{
  Rubin, D. B. (1987) \emph{Multiple Imputation for Nonresponse in
    Surveys.} Wiley.

  Schafer, J. L. (1996) \emph{Analysis of Incomplete Multivariate Data.}
  Chapman \& Hall.
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{prelim.mix}
\alias{prelim.mix}
\title{
  Preliminary Manipulations on Matrix of Incomplete Mixed Data
}
\description{
  This function performs grouping and sorting operations on a mixed
  dataset with missing values. It creates a list that is
  needed for input to \code{\link{em.mix}}, \code{\link{da.mix}},
  \code{\link{imp.mix}}, etc.
}
\usage{
prelim.mix(x, p)
}
\arguments{
  \item{x}{
    data matrix containing missing values. The rows of x correspond to
    observational units, and the columns to variables. Missing values are
    denoted by \code{NA}. The categorical variables must be in
    the first \code{p} columns
    of \code{x}, and they must be coded with consecutive positive integers
    starting with 1. For example, a binary variable must be coded as 1,2
    rather than 0,1.
  }
  \item{p}{
    number of categorical variables in x
}}
\value{
  a list of twenty-nine (!) components that summarize various features
  of x after the data have been collapsed, centered, scaled, and sorted
  by missingness patterns. Components that might be of interest to the
  user include:

  \item{nmis}{
    a vector of length \code{ncol(x)} containing the number of
    missing values for each variable in \code{x}. 
  }
  \item{r}{
    matrix of response indicators showing the missing data patterns in
    \code{x}.
    Observed values are indicated by 1 and missing values by 0. The row
    names give the number of observations in each pattern, and the columns
    correspond to the columns of \code{x}.
}}
\references{
  Schafer, J. L. (1996) \emph{Analysis of Incomplete Multivariate Data.}
  Chapman \& Hall, Chapter 9.
}
\seealso{
  \code{\link{em.mix}}, \code{\link{ecm.mix}},
  \code{\link{da.mix}}, \code{\link{dabipf.mix}}, \code{\link{imp.mix}},
  \code{\link{getparam.mix}}
}
\examples{
data(stlouis)
s <- prelim.mix(stlouis, 3)  # do preliminary manipulations 
s$nmis              # look at nmis
s$r                 # look at missing data patterns
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{rngseed}
\alias{rngseed}
\title{
  Initialize Random Number Generator Seed
}
\description{
  Initialize random number generator seed for mix package.
}
\usage{
rngseed(seed)
}
\arguments{
\item{seed}{
  a positive number, preferably a large integer.
}}
\value{
\code{NULL}.
}
\note{
  The random number generator seed must be set at least once
  by this function before the simulation or imputation functions 
  in this package (\code{\link{da.mix}}, \code{\link{imp.mix}}, etc.)
  can be used.
}

\keyword{models}

\eof
\name{stlouis}
\alias{stlouis}
\docType{data}
\title{St. Louis Risk Research Project}
\description{
  The St. Louis Risk Research Project was an observational study to
  assess the affects of parental psychological disorders on child
  development.  In the preliminary study, 69 families with 2 children
  were studied.
}
\usage{data(stlouis)}
\format{
  This is a numeric matrix with 69 rows and 7 columns:
  \tabular{rll}{
    \code{[,1]} \tab \code{G}  \tab Parental risk group\cr
    \code{[,2]} \tab \code{D1} \tab Symptoms, child 1\cr
    \code{[,3]} \tab \code{D2} \tab Symptoms, child 2\cr
    \code{[,4]} \tab \code{R1} \tab Reading score, child 1\cr
    \code{[,5]} \tab \code{V1} \tab Verbal score, child 1\cr
    \code{[,6]} \tab \code{R2} \tab Reading score, child 2\cr
    \code{[,7]} \tab \code{V2} \tab Verbal score, child 2
  }

  The parental risk group was coded 1, 2 or 3, from low or high, and the
  child symptoms 1 = low or 2 = high.  Missing values occur on all
  variables except \code{G}.
}
\source{
  Little, R. J. A.  and Schluchter, M. D. (1985), Maximum-likelihood
  estimation for mixed continuous and categorical data with missing
  values. \emph{Biometrika}, \bold{72}, 492--512.

  Schafer, J. L. (1996) \emph{Analysis of Incomplete Multivariate Data.}
  Chapman \& Hall. pp. 359--367.
}
\keyword{datasets}

\eof
